@@ -57,7 +57,7 @@ class ChClient:
         Any settings from https://clickhouse.yandex/docs/en/operations/settings
     """
 
-    __slots__ = ("_session", "url", "params", "_json", "_http_client")
+    __slots__ = ("_session", "url", "params", "headers", "_json", "_http_client")
 
     def __init__(
         self,
@@ -74,10 +74,11 @@ class ChClient:
         self._http_client = _http_client(session)
         self.url = url
         self.params = {}
+        self.headers = {}
         if user:
-            self.params["user"] = user
+            self.headers["X-ClickHouse-User"] = user
         if password:
-            self.params["password"] = password
+            self.headers["X-ClickHouse-Key"] = password
         if database:
             self.params["database"] = database
         if compress_response:
@@ -113,7 +114,9 @@ class ChClient:
         """
         try:
             await self._http_client.get(
-                url=self.url, params={**self.params, "query": "SELECT 1"}
+                url=self.url,
+                params={**self.params, "query": "SELECT 1"},
+                headers=self.headers,
             )
         except ChClientError:
             return False
@@ -171,7 +174,7 @@ class ChClient:
 
         if need_fetch:
             response = self._http_client.post_return_lines(
-                url=self.url, params=params, data=data
+                url=self.url, params=params, headers=self.headers, data=data
             )
             if is_json:
                 rf = FromJsonFabric(loads=self._json.loads)
@@ -187,7 +190,7 @@ class ChClient:
                     yield rf.new(line)
         else:
             await self._http_client.post_no_return(
-                url=self.url, params=params, data=data
+                url=self.url, params=params, headers=self.headers, data=data
             )
 
     async def execute(
@@ -203,7 +206,8 @@ class ChClient:
         :param str query: Clickhouse query string.
         :param args: Arguments for insert queries.
         :param bool json: Execute query in JSONEachRow mode.
-        :param Optional[Dict[str, Any]] params: Params to escape inside query string on field values.
+        :param Optional[Dict[str, Any]] params: Params to escape
+               inside query string on field values.
         :param str query_id: Clickhouse query_id.
 
         Usage:
@@ -211,7 +215,9 @@ class ChClient:
         .. code-block:: python
 
             await client.execute(
-                "CREATE TABLE t (a UInt8, b Tuple(Date, Nullable(Float32))) ENGINE = Memory"
+                "CREATE TABLE t (a UInt8,
+                                 b Tuple(Date, Nullable(Float32))
+                                 ) ENGINE = Memory"
             )
             await client.execute(
                 "INSERT INTO t VALUES",
@@ -245,7 +251,8 @@ class ChClient:
         :param bool json: Execute query in JSONEachRow mode.
         :param Optional[Dict[str, Any]] params: Params to escape inside query string.
         :param str query_id: Clickhouse query_id.
-        :param decode: Decode to python types. If False, returns bytes for each field instead.
+        :param decode: Decode to python types.
+                       If False, returns bytes for each field instead.
 
         Usage:
 
@@ -282,7 +289,8 @@ class ChClient:
         :param bool json: Execute query in JSONEachRow mode.
         :param Optional[Dict[str, Any]] params: Params to escape inside query string.
         :param str query_id: Clickhouse query_id.
-        :param decode: Decode to python types. If False, returns bytes for each field instead.
+        :param decode: Decode to python types. If False,
+                       returns bytes for each field instead.
 
         Usage:
 
@@ -322,13 +330,15 @@ class ChClient:
         query_id: str = None,
         decode: bool = True,
     ) -> Any:
-        """Execute query and fetch first value of the first row from query result or None.
+        """Execute query and fetch first value of the first
+           row from query result or None.
 
         :param query: Clickhouse query string.
         :param bool json: Execute query in JSONEachRow mode.
         :param Optional[Dict[str, Any]] params: Params to escape inside query string.
         :param str query_id: Clickhouse query_id.
-        :param decode: Decode to python types. If False, returns bytes for each field instead.
+        :param decode: Decode to python types.
+                       If False, returns bytes for each field instead.
 
         Usage:
 
@@ -366,7 +376,8 @@ class ChClient:
         :param bool json: Execute query in JSONEachRow mode.
         :param Optional[Dict[str, Any]] params: Params to escape inside query string.
         :param str query_id: Clickhouse query_id.
-        :param decode: Decode to python types. If False, returns bytes for each field instead.
+        :param decode: Decode to python types.
+                       If False, returns bytes for each field instead.
 
         Usage:
 
