@@ -1,4 +1,5 @@
 import datetime as dt
+import json
 import re
 from abc import ABC, abstractmethod
 from decimal import Decimal
@@ -31,10 +32,10 @@ RE_TUPLE = re.compile(r"^Tuple\((.*)\)$")
 RE_ARRAY = re.compile(r"^Array\((.*)\)$")
 RE_NULLABLE = re.compile(r"^Nullable\((.*)\)$")
 RE_LOW_CARDINALITY = re.compile(r"^LowCardinality\((.*)\)$")
+RE_MAP = re.compile(r"^Map\((.*)\)$")
 
 
 class BaseType(ABC):
-
     __slots__ = ("name", "container")
 
     ESC_CHR_MAPPING = {
@@ -270,7 +271,6 @@ class IPv6Type(BaseType):
 
 
 class TupleType(BaseType):
-
     __slots__ = ("name", "types")
 
     def __init__(self, name: str, **kwargs):
@@ -291,8 +291,30 @@ class TupleType(BaseType):
         return b"(" + b",".join(py2ch(elem) for elem in value) + b")"
 
 
-class ArrayType(BaseType):
+class MapType(BaseType):
+    __slots__ = ("name", "key_type", "value_type")
 
+    def __init__(self, name: str, **kwargs):
+        super().__init__(name, **kwargs)
+        tps = RE_MAP.findall(name)[0]
+        comma_index = tps.index(",")
+        self.key_type = what_py_type(tps[:comma_index], container=True)
+        self.value_type = what_py_type(tps[comma_index + 1 :], container=True)
+
+    def p_type(self, string: Any) -> dict:
+        if isinstance(string, str):
+            string = json.loads(string.replace("'", '"'))
+        return {
+            self.key_type.p_type(key): self.value_type.p_type(val)
+            for key, val in string.items()
+        }
+
+    @staticmethod
+    def unconvert(value) -> bytes:
+        return json2ch(value, dumps=json.dumps).replace('"', "'").encode()
+
+
+class ArrayType(BaseType):
     __slots__ = ("name", "type")
 
     def __init__(self, name: str, **kwargs):
@@ -308,13 +330,12 @@ class ArrayType(BaseType):
 
 
 class NullableType(BaseType):
-
     __slots__ = ("name", "type")
     NULLABLE = {r"\N", "NULL"}
 
-    def __init__(self, name: str, **kwargs):
+    def __init__(self, name: str, container: bool = False, **kwargs):
         super().__init__(name, **kwargs)
-        self.type = what_py_type(RE_NULLABLE.findall(name)[0])
+        self.type = what_py_type(RE_NULLABLE.findall(name)[0], container=container)
 
     def p_type(self, string: str) -> Any:
         if string in self.NULLABLE:
@@ -335,7 +356,6 @@ class NothingType(BaseType):
 
 
 class LowCardinalityType(BaseType):
-
     __slots__ = ("name", "type")
 
     def __init__(self, name: str, container: bool = False, **kwargs):
@@ -379,6 +399,7 @@ CH_TYPES_MAPPING = {
     "DateTime": DateTimeType,
     "DateTime64": DateTime64Type,
     "Tuple": TupleType,
+    "Map": MapType,
     "Array": ArrayType,
     "Nullable": NullableType,
     "Nothing": NothingType,
@@ -400,6 +421,7 @@ PY_TYPES_MAPPING = {
     dt.date: DateType.unconvert,
     dt.datetime: DateTimeType.unconvert,
     tuple: TupleType.unconvert,
+    dict: MapType.unconvert,
     list: ArrayType.unconvert,
     type(None): NullableType.unconvert,
     UUID: UUIDType.unconvert,
@@ -436,7 +458,8 @@ def py2ch(value):
         raise ChClientError(
             f"Unrecognized type: '{type(value)}'. "
             f"The value type should be exactly one of "
-            f"int, float, str, dt.date, dt.datetime, tuple, list, uuid.UUID (or None). "
+            f"int, float, str, dt.date, dt.datetime, "
+            f"dict, tuple, list, uuid.UUID (or None). "
             f"No subclasses yet."
         )
 
